@@ -8,7 +8,7 @@ package Lemonldap::NG::Portal::AuthNull;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.2.0';
 
 ## @apmethod int authInit()
 # Does nothing
@@ -64,6 +64,12 @@ sub authForce {
     return 0;
 }
 
+## @method string getDisplayType
+# @return display type
+sub getDisplayType {
+    return "";
+}
+
 1;
 __END__
 
