@@ -8,13 +8,13 @@ package Lemonldap::NG::Portal::MailReset;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1';
+our $VERSION = '1.2.2';
 
 use Lemonldap::NG::Portal::Simple qw(:all);
 use base qw(Lemonldap::NG::Portal::SharedConf Exporter);
 use HTML::Template;
 use Encode;
-use POSIX;
+use POSIX qw(strftime);
 
 #inherits Lemonldap::NG::Portal::_SMTP
 
@@ -220,19 +220,16 @@ sub sendConfirmationMail {
 
     $self->lmLog( "Mail expiration timestamp: $expTimestamp", 'debug' );
 
-    $self->{expMailDate} =
-      &POSIX::strftime( "%d/%m/%Y", localtime $expTimestamp );
-    $self->{expMailTime} = &POSIX::strftime( "%H:%M", localtime $expTimestamp );
+    $self->{expMailDate} = strftime( "%d/%m/%Y", localtime $expTimestamp );
+    $self->{expMailTime} = strftime( "%H:%M",    localtime $expTimestamp );
 
     # Mail session start date
     my $startTimestamp = $self->{mailSessionStartTimestamp};
 
     $self->lmLog( "Mail start timestamp: $startTimestamp", 'debug' );
 
-    $self->{startMailDate} =
-      &POSIX::strftime( "%d/%m/%Y", localtime $startTimestamp );
-    $self->{startMailTime} =
-      &POSIX::strftime( "%H:%M", localtime $startTimestamp );
+    $self->{startMailDate} = strftime( "%d/%m/%Y", localtime $startTimestamp );
+    $self->{startMailTime} = strftime( "%H:%M",    localtime $startTimestamp );
 
     # Ask if user want another confirmation email
     if ( $self->{mail_already_sent} and !$self->param('resendconfirmation') ) {
@@ -320,6 +317,7 @@ sub changePassword {
     }
 
     # Modify the password
+    $self->{portalRequireOldPassword} = 0;
     my $result = $self->modifyPassword();
 
     # Mail token can be used only one time, delete the session if all is ok
