@@ -12,7 +12,7 @@ use Lemonldap::NG::Portal::_LibAccess;
 use base qw(Lemonldap::NG::Portal::_LibAccess);
 use Clone qw(clone);
 
-our $VERSION  = '1.0.5';
+our $VERSION  = '1.1.0';
 our $catlevel = 0;
 
 ## @method void menuInit()
@@ -23,7 +23,7 @@ sub menuInit {
     $self->{apps}->{imgpath} ||= '/apps/';
 
     # Modules to display
-    $self->{menuModules} ||= "Appslist ChangePassword Logout";
+    $self->{menuModules} ||= "Appslist ChangePassword LoginHistory Logout";
     $self->{menuDisplayModules} = $self->displayModules();
 
     # Extract password from POST data
@@ -34,13 +34,22 @@ sub menuInit {
     $self->{user}            = $self->{sessionInfo}->{_user};
 
     # Try to change password
-    $self->{menuError} = $self->_subProcess(qw(passwordDBInit modifyPassword));
+    $self->{menuError} =
+      $self->_subProcess(qw(passwordDBInit modifyPassword sendPasswordMail))
+      unless $self->{ignorePasswordChange};
 
     # Default menu error code
     $self->{menuError} ||= $self->{error};
 
     # Tab to display
-    $self->{menuDisplayTab} = "appslist";
+    # Get the tab URL parameter
+    $self->{menuDisplayTab} = $self->param("tab") || "none";
+
+    # Default to appslist if invalid tab URL parameter
+    $self->{menuDisplayTab} = "appslist"
+      unless ( $self->{menuDisplayTab} =~ /^(password|logout)$/ );
+
+    # Force password tab in case of password error
     $self->{menuDisplayTab} = "password"
       if (
         (
@@ -56,15 +65,17 @@ sub menuInit {
                     33,    #PE_PP_EXP_WARNING
                     34,    #PE_PASSWORD_MISMATCH
                     39,    #PE_BADOLDPASSWORD
+                    74,    #PE_MUST_SUPPLY_OLD_PASSWORD
                 )
             )
         )
       );
 
     # Application list for old templates
-    # TODO create an option to activate them, off by default
-    $self->{menuAppslistMenu} = $self->appslistMenu();
-    $self->{menuAppslistDesc} = $self->appslistDescription();
+    if ( $self->{useOldMenuItems} ) {
+        $self->{menuAppslistMenu} = $self->appslistMenu();
+        $self->{menuAppslistDesc} = $self->appslistDescription();
+    }
 
     return;
 }
@@ -91,6 +102,16 @@ sub displayModules {
             my $moduleHash = { $module => 1 };
             $moduleHash->{'APPSLIST_LOOP'} = $self->appslist()
               if ( $module eq 'Appslist' );
+            if ( $module eq 'LoginHistory' ) {
+                $moduleHash->{'SUCCESS_LOGIN'} =
+                  $self->mkSessionArray(
+                    $self->{sessionInfo}->{loginHistory}->{successLogin},
+                    "", 0, 0 );
+                $moduleHash->{'FAILED_LOGIN'} =
+                  $self->mkSessionArray(
+                    $self->{sessionInfo}->{loginHistory}->{failedLogin},
+                    "", 0, 1 );
+            }
             push @$displayModules, $moduleHash;
         }
     }
