@@ -9,9 +9,16 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use MIME::Base64;
 
-our $VERSION = '0.992';
+our $VERSION = '1.0.0';
 our $initDone;
 
+BEGIN {
+    eval {
+        require threads::shared;
+        threads::shared::share($initDone);
+    };
+}
+
 ## @apmethod int init()
 # Checks if remote portal parameters are set.
 # @return Lemonldap::NG::Portal constant
