@@ -10,17 +10,17 @@ use Lemonldap::NG::Common::Conf::SAML::Metadata;
 use XML::Simple;
 use MIME::Base64;
 use String::Random;
-use LWP::UserAgent;    # SOAP call
-use HTTP::Request;     # SOAP call
-use POSIX;             # Convert SAML2 date into timestamp
-use Time::Local;       # Convert SAML2 date into timestamp
-use Encode;            # Encode attribute values
-use URI;               # Get metadata URL path
+use LWP::UserAgent;        # SOAP call
+use HTTP::Request;         # SOAP call
+use POSIX qw(strftime);    # Convert SAML2 date into timestamp
+use Time::Local;           # Convert SAML2 date into timestamp
+use Encode;                # Encode attribute values
+use URI;                   # Get metadata URL path
 
 # Special comments for doxygen
 #inherits Lemonldap::NG::Common::Conf::SAML::Metadata protected service_metadata
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.2.2';
 our $samlCache;
 our $initGlibDone;
 
@@ -2272,7 +2272,7 @@ sub timestamp2samldate {
     my ( $self, $timestamp ) = splice @_;
 
     my @t = gmtime($timestamp);
-    my $samldate = POSIX::strftime( "%Y-%m-%dT%TZ", @t );
+    my $samldate = strftime( "%Y-%m-%dT%TZ", @t );
 
     $self->lmLog( "Convert timestamp $timestamp in SAML2 date: $samldate",
         'debug' );
